summaryrefslogtreecommitdiffstats
path: root/ash/shell.h
diff options
context:
space:
mode:
Diffstat (limited to 'ash/shell.h')
-rw-r--r--ash/shell.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/ash/shell.h b/ash/shell.h
index 5aac16a..10f972a 100644
--- a/ash/shell.h
+++ b/ash/shell.h
@@ -10,6 +10,7 @@
#include <vector>
#include "ash/ash_export.h"
+#include "ash/wm/shelf_auto_hide_behavior.h"
#include "base/basictypes.h"
#include "base/compiler_specific.h"
#include "base/gtest_prod_util.h"
@@ -209,9 +210,9 @@ class ASH_EXPORT Shell {
// Force the shelf to query for it's current visibility state.
void UpdateShelfVisibility();
- // Sets/gets whether the shelf always auto-hides.
- void SetShelfAlwaysAutoHide(bool value);
- bool GetShelfAlwaysAutoHide() const;
+ // Sets/gets the shelf auto-hide behavior.
+ void SetShelfAutoHideBehavior(ShelfAutoHideBehavior behavior);
+ ShelfAutoHideBehavior GetShelfAutoHideBehavior() const;
// TODO(sky): don't expose this!
internal::ShelfLayoutManager* shelf() const { return shelf_; }